@@ -14,6 +14,10 @@ from requests.adapters import HTTPAdapter
 import inspect
 import json
 from peutils.textutil import gen_uuid
+from peutils.pcd_py3 import PointCloud
+import numpy as np
+
+
 
 def get_session(retry=3):
     session = requests.Session()
@@ -44,8 +48,6 @@ def dict_adapter(d:dict,out_adapter=None, rename:dict=None):
             d = {rename.get(k, k): v for k, v in d.items()}
     return d
 
-from peutils.pcd_py3 import PointCloud
-import numpy as np
 
 def get_pointlist_from_path(path,fltype=None,dtype=None):
     # path可以是当时标注的点云对应文件，也可以是客户标注的对应文件，如果是客户的文件，我们要注意是否有去过Nan点，这种需要补点.
@@ -254,27 +256,65 @@ class Lidar3dImageRect():
 categoryColor一般为空不要用，
 '''
 class ImgInstance():
-    def __init__(self,id,category,number,categoryName,categoryColor,ist_attr):
+    def __init__(self,id,category,number,categoryName=None,ist_attr=None):
         # self.frameNum = frameNum  # frameNum用子物体的
         self.id = id
         self.category = category
         self.categoryName = categoryName
         self.number = number
-        # self.categoryColor = categoryColor
+        # self.categoryColor = categoryColor # 不用这个属性
         self.ist_attr = ist_attr
         self.obj_list = []
 
     def __repr__(self):
         return f"{self.id} {self.category} {self.number} {len(self.obj_list)}T"
 
+    def to_pre_dict(self):
+        _pre_data_dict = {
+            "id":self.id,
+            "category":self.category,
+            "number": self.number,
+            "attributes":self.ist_attr,
+            "children":[
+            ]
+        }
+
+        ## 计算child_dict
+        child_dict = dict()
+        for item in self.obj_list:
+            child_id = item.id
+            if child_id not in child_dict:
+                child_dict[child_id] = {
+                    "id": item.id,
+                    "name": item.category,
+                    "number": item.number,
+                    "cameras": [{
+                        "camera": "default",
+                        "frames": []
+                    }]
+                }
+            ## 添加这条数据到frames信息中
+            child_dict[child_id]["cameras"][0]["frames"].append({
+                "frameIndex": item.frameNum,
+                "isKeyFrame": True,
+                "shapeType": item.shapeType,
+                "shape": item.shape,
+                "order": item.order,
+                "attributes": item.img_attr
+            })
+        for _,v in child_dict.items():
+            _pre_data_dict["children"].append(v)
+        return  _pre_data_dict
+
+
 
 
 class Img2Dobj():
     def __init__(self,instance:ImgInstance,
                  frameNum,id,number,category,
-                 displayName, color,
-                 shapeType,shape,order,img_attr,
-                 isOCR=None,OCRText=""
+                 shapeType,order=None,shape=None,img_attr=None,
+                 displayName="", color="",
+                 isOCR=None,OCRText=None
                  ):
         self.instance = instance
         self.frameNum = frameNum
@@ -294,6 +334,19 @@ class Img2Dobj():
         return f"F{self.frameNum} {self.id} {self.category} {self.number} {self.shapeType} Order:{self.order} <-[{self.instance.category}]"
 
 
+class AudioCutObj():
+    def __init__(self,frameNum,id,number, start,end,block_attr,line_contents,category=""):
+        self.frameNum = frameNum
+        self.id = id
+        self.number = number
+        self.category = category
+        self.start = start
+        self.end = end
+        self.block_attr = block_attr
+        self.line_contents = line_contents # 对应content字段
+
+    def __repr__(self):
+        return f"{self.id} {self.category} {self.number} {self.start} {self.end}"
 
 
 # type points 点,polyline 线
