@@ -70,7 +70,7 @@ class LidarBoxFrame():
         quaternion =dict_adapter(item["quaternion"],out_adapter=self.config.number_adpter_func)
 
         ### 解析点云数量
-        if item.get("pointCount") and item.get("pointCount").get("lidar"):
+        if item.get("pointCount") and item.get("pointCount").get("lidar") is not None:
             pointCount = item["pointCount"]["lidar"]
         else:
             pointCount = None
@@ -230,7 +230,7 @@ class LidarBoxParse(CommonBaseMixIn):
             self.config.seq_func = gen_uuid_seq(start=self.config.seq_start)
 
         self.raw_data = self.get_raw_data(url) # 获取JSON字典数据数据
-        self.frames_lst = self.parse_by_frame()
+        self.frames_lst, self.frame_length = self.parse_by_frame()
 
 
     def check_frames_error(self):
@@ -267,7 +267,7 @@ class LidarBoxParse(CommonBaseMixIn):
                 config= self.config
             )
             frames_lst.append(frame)
-        return frames_lst
+        return frames_lst,len(frames_lst)
 
 
 
@@ -295,7 +295,7 @@ if __name__ =="__main__":
                              seq_start = 0, # 如果是 gid,fid,或者frame_id 需要提供seq_start， 如果是0就是从1开始编号，如果是-1就是从0开始编号
                              overflow= False
                          ))
-
+    lidar.check_frames_error()
     # pprint(lidar.frames_lst[49].lidar_dict)
     # pprint(lidar.frames_lst[0].lidar_dict["06e41560-32ac-436d-a0c0-3e4aae7d4858"].rotation)
     # print(lidar.check_frames_error())
